( cd usr/bin ; rm -rf uncompress )
( cd usr/bin ; ln -sf compress uncompress )
( cd bin ; rm -rf compress )
( cd bin ; ln -sf /usr/bin/compress compress )
( cd bin ; rm -rf uncompress )
( cd bin ; ln -sf compress uncompress )
